[−][src]Struct pointcloud::label_sources::VecLabels
Uses a vector to label your data. It can be 1 hot encoded, but if you do that you should use SmallIntLabels
Implementations
impl VecLabels[src]
pub fn new(
labels: Vec<f32>,
label_dim: usize,
mask: Option<Vec<bool>>
) -> VecLabels[src]
labels: Vec<f32>,
label_dim: usize,
mask: Option<Vec<bool>>
) -> VecLabels
Creates a new vec label.
pub fn dim(&self) -> usize[src]
The dimension of the vectors this labelset contains
pub fn one_hot_to_int(&self) -> SmallIntLabels[src]
coverts a one-hot encoding to a integer label set
pub fn binary_to_int(&self) -> SmallIntLabels[src]
coverts a binary encoding to a integer label set